The olr function runs all the possible combinations of linear regressions with all of the
dependent variables against the independent variable and returns the statistical summary
of either the greatest adjusted R-squared or R-squared term. Adding an additional explanatory variable to the regression equation increases the R-squared or
adjusted R-squared terms even if the variable is not 'significant'. Thus, adjusted R-squared was preferred, but this was developed to eliminate that conundrum.


dataset = pd.read_csv('C:\Rstuff\olr\inst\extdata\oildata.csv')
responseName = dataset[['OilPrices']]
predictorNames = dataset[['SP500', 'RigCount', 'API', 'Field_Production', 'RefinerNetInput', 'OperableCapacity', 'Imports', 'StocksExcludingSPR']]

The TRUE or FALSE in the olr function, specifies either the adjusted R-squared or the R-squared regression summary, respectfully.

When responseName and predictorNames are None (NULL), then the first column in the dataset is set as the responseName and the remaining columns are the predictorNames.

Adjusted R-squared <br />
olr(datasetname, resvarname = None, expvarnames = None, adjr2 = "True")

R-squared <br />
olr(datasetname, resvarname = None, expvarnames = None, adjr2 = "False")

list of summaries <br />
olrmodels(datasetname, resvarname = None, expvarnames = None)

list of formulas <br />
olrformulas(datasetname, resvarname = None, expvarnames = None)

list of forumlas with the dependant variables in ascending order <br />
olrformulasorder(datasetname, resvarname = None, expvarnames = None)

the list of adjusted R-squared terms <br />
adjr2list(datasetname, resvarname = None, expvarnames = None)

the list of R-squared terms <br />
r2list(datasetname, resvarname = None, expvarnames = None)

An R version of this package olr is available on CRAN.